summaryrefslogtreecommitdiff
path: root/games
diff options
context:
space:
mode:
Diffstat (limited to 'games')
-rw-r--r--games/devtest/mods/testnodes/textures.lua15
1 files changed, 4 insertions, 11 deletions
diff --git a/games/devtest/mods/testnodes/textures.lua b/games/devtest/mods/testnodes/textures.lua
index e0724c229..af3b7f468 100644
--- a/games/devtest/mods/testnodes/textures.lua
+++ b/games/devtest/mods/testnodes/textures.lua
@@ -51,23 +51,16 @@ for a=1,#alphas do
groups = { dig_immediate = 3 },
})
- -- Transparency set via "alpha" parameter
+ -- Transparency set via texture modifier
minetest.register_node("testnodes:alpha_"..alpha, {
description = S("Alpha Test Node (@1)", alpha),
- -- It seems that only the liquid drawtype supports the alpha parameter
- drawtype = "liquid",
+ drawtype = "glasslike",
paramtype = "light",
tiles = {
- "testnodes_alpha.png",
+ "testnodes_alpha.png^[opacity:" .. alpha,
},
- alpha = alpha,
-
+ use_texture_alpha = true,
- liquidtype = "source",
- liquid_range = 0,
- liquid_viscosity = 0,
- liquid_alternative_source = "testnodes:alpha_"..alpha,
- liquid_alternative_flowing = "testnodes:alpha_"..alpha,
groups = { dig_immediate = 3 },
})
end